@@ -1,5 +1,6 @@
 /* Define a target vector and some small routines for a variant of a.out.
-   Copyright (C) 1990, 91, 92, 93, 94, 95, 1996 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 92, 93, 94, 95, 96, 1997
+   Free Software Foundation, Inc.
 
 This file is part of BFD, the Binary File Descriptor library.
 
@@ -22,11 +23,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #include "aout/ar.h"
 /*#include "libaout.h"*/
 
-extern reloc_howto_type * NAME(aout,reloc_type_lookup) ();
+#ifndef SEGMENT_SIZE
+#define SEGMENT_SIZE TARGET_PAGE_SIZE
+#endif
+
+extern reloc_howto_type * NAME(aout,reloc_type_lookup)
+  PARAMS ((bfd *, bfd_reloc_code_real_type));
 
 /* Set parameters about this a.out file that are machine-dependent.
    This routine is called from some_aout_object_p just before it returns.  */
 #ifndef MY_callback
+
+static const bfd_target *MY(callback) PARAMS ((bfd *));
+
 static const bfd_target *
 MY(callback) (abfd)
      bfd *abfd;
@@ -43,6 +52,23 @@ MY(callback) (abfd)
   obj_datasec (abfd)->vma = N_DATADDR(*execp);
   obj_bsssec  (abfd)->vma = N_BSSADDR(*execp);
 
+  /* For some targets, if the entry point is not in the same page
+     as the start of the text, then adjust the VMA so that it is.
+     FIXME: Do this with a macro like SET_ARCH_MACH instead?  */
+  if (aout_backend_info (abfd)->entry_is_text_address
+      && execp->a_entry > obj_textsec (abfd)->vma)
+    {
+      bfd_vma adjust;
+
+      adjust = execp->a_entry - obj_textsec (abfd)->vma;
+      /* Adjust only by whole pages. */
+      adjust &= ~(TARGET_PAGE_SIZE - 1);
+      obj_textsec (abfd)->vma += adjust;
+      obj_datasec (abfd)->vma += adjust;
+      obj_bsssec (abfd)->vma += adjust;
+    }
+
+  /* Set the load addresses to be the same as the virtual addresses.  */
   obj_textsec (abfd)->lma = obj_textsec (abfd)->vma;
   obj_datasec (abfd)->lma = obj_datasec (abfd)->vma;
   obj_bsssec (abfd)->lma = obj_bsssec (abfd)->vma;
@@ -66,6 +92,15 @@ MY(callback) (abfd)
   bfd_default_set_arch_mach(abfd, DEFAULT_ARCH, 0);
 #endif
 
+  /* The number of relocation records.  This must be called after
+     SET_ARCH_MACH.  It assumes that SET_ARCH_MACH will set
+     obj_reloc_entry_size correctly, if the reloc size is not
+     RELOC_STD_SIZE.  */
+  obj_textsec (abfd)->reloc_count =
+    execp->a_trsize / obj_reloc_entry_size (abfd);
+  obj_datasec (abfd)->reloc_count =
+    execp->a_drsize / obj_reloc_entry_size (abfd);
+
   /* Now that we know the architecture, set the alignments of the
      sections.  This is normally done by NAME(aout,new_section_hook),
      but when the initial sections were created the architecture had
@@ -90,11 +125,7 @@ MY(callback) (abfd)
      Sizes get set in set_sizes callback, later.  */
 #if 0
   adata(abfd).page_size = TARGET_PAGE_SIZE;
-#ifdef SEGMENT_SIZE
   adata(abfd).segment_size = SEGMENT_SIZE;
-#else
-  adata(abfd).segment_size = TARGET_PAGE_SIZE;
-#endif
   adata(abfd).exec_bytes_size = EXEC_BYTES_SIZE;
 #endif
 
@@ -105,6 +136,8 @@ MY(callback) (abfd)
 #ifndef MY_object_p
 /* Finish up the reading of an a.out file header */
 
+static const bfd_target *MY(object_p) PARAMS ((bfd *));
+
 static const bfd_target *
 MY(object_p) (abfd)
      bfd *abfd;
@@ -166,6 +199,9 @@ MY(object_p) (abfd)
 
 
 #ifndef MY_mkobject
+
+static boolean MY(mkobject) PARAMS ((bfd *));
+
 static boolean
 MY(mkobject) (abfd)
      bfd *abfd;
@@ -175,11 +211,7 @@ MY(mkobject) (abfd)
 #if 0 /* Sizes get set in set_sizes callback, later, after we know
 	 the architecture and machine.  */
   adata(abfd).page_size = TARGET_PAGE_SIZE;
-#ifdef SEGMENT_SIZE
   adata(abfd).segment_size = SEGMENT_SIZE;
-#else
-  adata(abfd).segment_size = TARGET_PAGE_SIZE;
-#endif
   adata(abfd).exec_bytes_size = EXEC_BYTES_SIZE;
 #endif
   return true;
@@ -195,6 +227,9 @@ MY(mkobject) (abfd)
    section contents, and copy_private_bfd_data is not called until
    after the section contents have been set.  */
 
+static boolean MY_bfd_copy_private_section_data
+  PARAMS ((bfd *, asection *, bfd *, asection *));
+
 /*ARGSUSED*/
 static boolean
 MY_bfd_copy_private_section_data (ibfd, isec, obfd, osec)
@@ -203,7 +238,8 @@ MY_bfd_copy_private_section_data (ibfd, isec, obfd, osec)
      bfd *obfd;
      asection *osec;
 {
-  if (bfd_get_flavour (obfd) == bfd_target_aout_flavour)
+  if (bfd_get_flavour (ibfd) == bfd_target_aout_flavour
+      && bfd_get_flavour (obfd) == bfd_target_aout_flavour)
     obj_aout_subformat (obfd) = obj_aout_subformat (ibfd);
   return true;
 }
@@ -236,17 +272,15 @@ MY(write_object_contents) (abfd)
 #endif
 
 #ifndef MY_set_sizes
+
+static boolean MY(set_sizes) PARAMS ((bfd *));
+
 static boolean
 MY(set_sizes) (abfd)
      bfd *abfd;
 {
   adata(abfd).page_size = TARGET_PAGE_SIZE;
-
-#ifdef SEGMENT_SIZE
   adata(abfd).segment_size = SEGMENT_SIZE;
-#else
-  adata(abfd).segment_size = TARGET_PAGE_SIZE;
-#endif
 
 #ifdef ZMAGIC_DISK_BLOCK_SIZE
   adata(abfd).zmagic_disk_block_size = ZMAGIC_DISK_BLOCK_SIZE;
@@ -272,6 +306,9 @@ MY(set_sizes) (abfd)
 #ifndef MY_text_includes_header
 #define MY_text_includes_header 0
 #endif
+#ifndef MY_entry_is_text_address
+#define MY_entry_is_text_address 0
+#endif
 #ifndef MY_exec_header_not_counted
 #define MY_exec_header_not_counted 0
 #endif
@@ -297,6 +334,7 @@ MY(set_sizes) (abfd)
 static CONST struct aout_backend_data MY(backend_data) = {
   MY_zmagic_contiguous,
   MY_text_includes_header,
+  MY_entry_is_text_address,
   MY_exec_hdr_flags,
   0,				/* text vma? */
   MY_set_sizes,
@@ -339,6 +377,8 @@ MY_final_link_callback (abfd, ptreloff, pdreloff, psymoff)
 /* Final link routine.  We need to use a call back to get the correct
    offsets in the output file.  */
 
+static boolean MY_bfd_final_link PARAMS ((bfd *, struct bfd_link_info *));
+
 static boolean
 MY_bfd_final_link (abfd, info)
      bfd *abfd;
@@ -512,8 +552,8 @@ MY_bfd_final_link (abfd, info)
 #define MY_bfd_set_private_flags _bfd_generic_bfd_set_private_flags
 #endif
 
-#ifndef MY_bfd_is_local_label
-#define MY_bfd_is_local_label bfd_generic_is_local_label
+#ifndef MY_bfd_is_local_label_name
+#define MY_bfd_is_local_label_name bfd_generic_is_local_label_name
 #endif
 
 #ifndef MY_bfd_free_cached_info
