@@ -186,6 +186,10 @@ _bfd_elf_link_record_dynamic_symbol (info, h)
   if (h->dynindx == -1)
     {
       struct bfd_strtab_hash *dynstr;
+      char *p, *alc;
+      const char *name;
+      boolean copy;
+      bfd_size_type indx;
 
       h->dynindx = elf_hash_table (info)->dynsymcount;
       ++elf_hash_table (info)->dynsymcount;
@@ -199,11 +203,34 @@ _bfd_elf_link_record_dynamic_symbol (info, h)
 	    return false;
 	}
 
-      h->dynstr_index = ((unsigned long)
-			 _bfd_stringtab_add (dynstr, h->root.root.string,
-					     true, false));
-      if (h->dynstr_index == (unsigned long) -1)
+      /* We don't put any version information in the dynamic string
+         table.  */
+      name = h->root.root.string;
+      p = strchr (name, ELF_VER_CHR);
+      if (p == NULL)
+	{
+	  alc = NULL;
+	  copy = false;
+	}
+      else
+	{
+	  alc = bfd_malloc (p - name + 1);
+	  if (alc == NULL)
+	    return false;
+	  strncpy (alc, name, p - name);
+	  alc[p - name] = '\0';
+	  name = alc;
+	  copy = true;
+	}
+
+      indx = _bfd_stringtab_add (dynstr, name, true, copy);
+
+      if (alc != NULL)
+	free (alc);
+
+      if (indx == (bfd_size_type) -1)
 	return false;
+      h->dynstr_index = indx;
     }
 
   return true;
@@ -318,12 +345,18 @@ _bfd_elf_create_linker_section (abfd, info, which, defaults)
 	}
     }
 
+#if 0
+  /* This does not make sense.  The sections which may exist in the
+     object file have nothing to do with the sections we want to
+     create.  */
+
   /* Find the related sections if they have been created */
   if (lsect->bss_name && !lsect->bss_section)
     lsect->bss_section = bfd_get_section_by_name (dynobj, lsect->bss_name);
 
   if (lsect->rel_name && !lsect->rel_section)
     lsect->rel_section = bfd_get_section_by_name (dynobj, lsect->rel_name);
+#endif
 
   return lsect;
 }
