@@ -1,5 +1,5 @@
 /* BFD back-end for oasys objects.
-   Copyright 1990, 1991, 1992, 1993, 1994, 1995 Free Software Foundation, Inc.
+   Copyright 1990, 91, 92, 93, 94, 95, 96, 1997 Free Software Foundation, Inc.
    Written by Steve Chamberlain of Cygnus Support, <sac@cygnus.com>.
 
 This file is part of BFD, the Binary File Descriptor library.
@@ -118,10 +118,7 @@ oasys_slurp_symbol_table (abfd)
   data->strings = bfd_alloc (abfd, data->symbol_string_length);
 #endif
   if (!data->symbols || !data->strings)
-    {
-      bfd_set_error (bfd_error_no_memory);
-      return false;
-    }
+    return false;
 
   dest_defined = data->symbols + abfd->symcount - 1;
 
@@ -310,10 +307,7 @@ oasys_archive_p (abfd)
     oasys_module_table_type record;
 
     if (!ar || !module)
-      {
-	bfd_set_error (bfd_error_no_memory);
-	return NULL;
-      }
+      return NULL;
 
     abfd->tdata.oasys_ar_data = ar;
     ar->module = module;
@@ -343,10 +337,7 @@ oasys_archive_p (abfd)
 
 	    module[i].name = bfd_alloc (abfd, 33);
 	    if (!module[i].name)
-	      {
-		bfd_set_error (bfd_error_no_memory);
-		return NULL;
-	      }
+	      return NULL;
 
 	    memcpy (module[i].name, record_ext.mod_name, 33);
 	    filepos +=
@@ -372,10 +363,7 @@ oasys_archive_p (abfd)
 
 	    module[i].name = bfd_alloc (abfd, record.module_name_size + 1);
 	    if (!module[i].name)
-	      {
-		bfd_set_error (bfd_error_no_memory);
-		return NULL;
-	      }
+	      return NULL;
 	    if (bfd_read ((PTR) module[i].name, 1, record.module_name_size,
 			  abfd)
 		!= record.module_name_size)
@@ -462,10 +450,7 @@ oasys_object_p (abfd)
 	      }
 	    buffer = bfd_alloc (abfd, 3);
 	    if (!buffer)
-	      {
-		bfd_set_error (bfd_error_no_memory);
-		goto fail;
-	      }
+	      goto fail;
 	    section_number = record.section.relb & RELOCATION_SECT_BITS;
 	    sprintf (buffer, "%u", section_number);
 	    s = bfd_make_section (abfd, buffer);
@@ -633,10 +618,7 @@ oasys_slurp_section_data (abfd)
 	      {
 		per->data = (bfd_byte *) bfd_zalloc (abfd, section->_raw_size);
 		if (!per->data)
-		  {
-		    bfd_set_error (bfd_error_no_memory);
-		    return false;
-		  }
+		  return false;
 		per->reloc_tail_ptr = (oasys_reloc_type **) & (section->relocation);
 		per->had_vma = false;
 		per->initialized = true;
@@ -703,10 +685,7 @@ oasys_slurp_section_data (abfd)
 				  bfd_alloc (abfd,
 					     sizeof (oasys_reloc_type));
 				  if (!r)
-				    {
-				      bfd_set_error (bfd_error_no_memory);
-				      return false;
-				    }
+				    return false;
 				  *(per->reloc_tail_ptr) = r;
 				  per->reloc_tail_ptr = &r->next;
 				  r->next = (oasys_reloc_type *) NULL;
@@ -750,10 +729,7 @@ oasys_slurp_section_data (abfd)
 				  bfd_alloc (abfd,
 					     sizeof (oasys_reloc_type));
 				  if (!r)
-				    {
-				      bfd_set_error (bfd_error_no_memory);
-				      return false;
-				    }
+				    return false;
 				  *(per->reloc_tail_ptr) = r;
 				  per->reloc_tail_ptr = &r->next;
 				  r->next = (oasys_reloc_type *) NULL;
@@ -819,10 +795,7 @@ oasys_new_section_hook (abfd, newsect)
   newsect->used_by_bfd = (PTR)
     bfd_alloc (abfd, sizeof (oasys_per_section_type));
   if (!newsect->used_by_bfd)
-    {
-      bfd_set_error (bfd_error_no_memory);
-      return false;
-    }
+    return false;
   oasys_per_section (newsect)->data = (bfd_byte *) NULL;
   oasys_per_section (newsect)->section = newsect;
   oasys_per_section (newsect)->offset = 0;
@@ -1348,10 +1321,7 @@ oasys_set_section_contents (abfd, section, location, offset, count)
 	  oasys_per_section (section)->data =
 	    (bfd_byte *) (bfd_alloc (abfd, section->_cooked_size));
 	  if (!oasys_per_section (section)->data)
-	    {
-	      bfd_set_error (bfd_error_no_memory);
-	      return false;
-	    }
+	    return false;
 	}
       (void) memcpy ((PTR) (oasys_per_section (section)->data + offset),
 		     location,
@@ -1376,10 +1346,7 @@ oasys_make_empty_symbol (abfd)
   oasys_symbol_type *new =
   (oasys_symbol_type *) bfd_zalloc (abfd, sizeof (oasys_symbol_type));
   if (!new)
-    {
-      bfd_set_error (bfd_error_no_memory);
-      return NULL;
-    }
+    return NULL;
   new->symbol.the_bfd = abfd;
   return &new->symbol;
 }
@@ -1488,9 +1455,10 @@ oasys_sizeof_headers (abfd, exec)
     PARAMS ((bfd *, unsigned int, struct orl *, unsigned int, int))) \
    bfd_true)
 #define oasys_read_ar_hdr bfd_nullvoidptr
+#define oasys_get_elt_at_index _bfd_generic_get_elt_at_index
 #define oasys_update_armap_timestamp bfd_true
 
-#define oasys_bfd_is_local_label bfd_generic_is_local_label
+#define oasys_bfd_is_local_label_name bfd_generic_is_local_label_name
 #define oasys_get_lineno _bfd_nosymbols_get_lineno
 #define oasys_bfd_make_debug_symbol _bfd_nosymbols_bfd_make_debug_symbol
 #define oasys_read_minisymbols _bfd_generic_read_minisymbols
@@ -1516,8 +1484,8 @@ const bfd_target oasys_vec =
 {
   "oasys",			/* name */
   bfd_target_oasys_flavour,
-  true,				/* target byte order */
-  true,				/* target headers byte order */
+  BFD_ENDIAN_BIG,		/* target byte order */
+  BFD_ENDIAN_BIG,		/* target headers byte order */
   (HAS_RELOC | EXEC_P |		/* object flags */
    HAS_LINENO | HAS_DEBUG |
    HAS_SYMS | HAS_LOCALS | WP_TEXT | D_PAGED),
