@@ -1,4 +1,4 @@
-/* BFD back-end for Intel 386 PE IMAGE COFF files.
+/* BFD back-end for PowerPC PE IMAGE COFF files.
    Copyright 1995 Free Software Foundation, Inc.
 
 This file is part of BFD, the Binary File Descriptor library.
@@ -36,6 +36,8 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #define COFF_IMAGE_WITH_PE
 #define COFF_WITH_PE
 
+#define COFF_LONG_SECTION_NAMES
+
 /* FIXME: Verify PCRELOFFSET is always false */
 
 #include "coff-ppc.c"
