@@ -199,6 +199,12 @@ parse_coff_type (abfd, symbols, types, coff_symno, ntype, pauxent, useaux,
 							      NULL, dhandle),
 					0, n - 1, false);
 	}
+      else
+	{
+	  fprintf (stderr, "%s: parse_coff_type: Bad type code 0x%x\n",
+		   program_name, ntype);
+	  return DEBUG_TYPE_NULL;
+	}
 
       return type;
     }
