@@ -1,9 +1,8 @@
 /* This file is tc-arm.h
+   Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
    Contributed by Richard Earnshaw (rwe@pegasus.esprit.ec.org)
 	Modified by David Taylor (dtaylor@armltd.co.uk)
 
-   Copyright (C) 1994, 1995 Free Software Foundation, Inc.
-
    This file is part of GAS, the GNU Assembler.
 
    GAS is free software; you can redistribute it and/or modify
@@ -17,11 +16,16 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GAS; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with GAS; see the file COPYING.  If not, write to the Free
+   Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 #define TC_ARM 1
 
+#ifndef TARGET_BYTES_BIG_ENDIAN
+#define TARGET_BYTES_BIG_ENDIAN 0
+#endif
+
 #define COFF_MAGIC ARMMAGIC
 #define TARGET_ARCH bfd_arch_arm
 
@@ -32,19 +36,11 @@
 #define LITTLE_ENDIAN 1234
 #define BIG_ENDIAN 4321
 
-/* If neither TARGET_BYTES_BIG_ENDIAN nor TARGET_BYTES_LITTLE_ENDIAN
-   is specified, default to little endian.  */
-#ifndef TARGET_BYTES_BIG_ENDIAN
-#ifndef TARGET_BYTES_LITTLE_ENDIAN
-#define TARGET_BYTES_LITTLE_ENDIAN
-#endif
-#endif
-
 #ifdef OBJ_AOUT
 #ifdef TE_RISCIX
 #define TARGET_FORMAT "a.out-riscix"
 #else
-#ifdef TARGET_BYTES_BIG_ENDIAN
+#if TARGET_BYTES_BIG_ENDIAN
 #define TARGET_FORMAT "a.out-arm-big"
 #else
 #define TARGET_FORMAT "a.out-arm-little"
@@ -75,6 +71,17 @@
 
 #define obj_fix_adjustable(fixP) 0
 
+#define TC_FIX_TYPE PTR
+#define TC_INIT_FIX_DATA(FIXP) ((FIXP)->tc_fix_data = NULL)
+
+#define TC_START_LABEL(C,STR) \
+  (c == ':' || (c == '/' && arm_data_in_code ()))
+int arm_data_in_code PARAMS ((void));
+
+#define tc_canonicalize_symbol_name(str) \
+  arm_canonicalize_symbol_name (str);
+char *arm_canonicalize_symbol_name PARAMS ((char *));
+
 #if 0	/* It isn't as simple as this */
 #define tc_frob_symbol(sym,punt)	\
 {	if (S_IS_LOCAL (sym))		\
@@ -104,9 +111,10 @@
 #define LOCAL_LABELS_FB  1
 
 /* Use defaults for OBJ_AOUT.  */
+#ifndef BFD_ASSEMBLER
 #ifndef OBJ_AOUT
 #define LOCAL_LABEL(name)	((name)[0] == '.' && (name)[1] == 'L')
-#define FAKE_LABEL_NAME		".L0\001"
+#endif
 #endif
 
 /* end of tc-arm.h */
