@@ -57,11 +57,11 @@ const relax_typeS md_relax_table[] = {
   /* bCC relaxing */
   {0x7f, -0x80, 2, 1},
   {0x7fff, -0x8000, 5, 2},
-  {0x7fffff, -0x8000000, 7, 0},
+  {0x7fffff, -0x800000, 7, 0},
   /* bCCx relaxing */
   {0x7f, -0x80, 3, 4},
   {0x7fff, -0x8000, 6, 5},
-  {0x7fffff, -0x8000000, 8, 0},
+  {0x7fffff, -0x800000, 8, 0},
   /* jsr relaxing */
   {0x7fff, -0x8000, 3, 7},
   {0x7fffff, -0x8000000, 5, 0},
@@ -378,6 +378,9 @@ md_convert_frag (abfd, sec, fragP)
   asection *sec;
   fragS *fragP;
 {
+  static unsigned long label_count = 0;
+  char buf[40];
+
   subseg_change (sec, 0);
   if (fragP->fr_subtype == 0)
     {
@@ -429,9 +432,11 @@ md_convert_frag (abfd, sec, fragP)
 	}
       fragP->fr_literal[offset] = opcode;
 
-      /* Set the displacement bits so that we branch around
-	 the unconditional branch.  */
-      fragP->fr_literal[offset + 1] = 0x5;
+      /* Create a fixup for the reversed conditional branch.  */
+      sprintf (buf, "%s_%d", FAKE_LABEL_NAME, label_count++);
+      fix_new (fragP, fragP->fr_fix + 1, 1,
+	       symbol_new (buf, sec, 0, fragP->fr_next),
+	       fragP->fr_offset + 1, 1, BFD_RELOC_8_PCREL);
 
       /* Now create the unconditional branch + fixup to the
 	 final target.  */
@@ -484,9 +489,11 @@ md_convert_frag (abfd, sec, fragP)
 	}
       fragP->fr_literal[offset] = opcode;
 
-      /* Set the displacement bits so that we branch around
-	 the unconditional branch.  */
-      fragP->fr_literal[offset + 1] = 0x7;
+      /* Create a fixup for the reversed conditional branch.  */
+      sprintf (buf, "%s_%d", FAKE_LABEL_NAME, label_count++);
+      fix_new (fragP, fragP->fr_fix + 1, 1,
+	       symbol_new (buf, sec, 0, fragP->fr_next),
+	       fragP->fr_offset + 1, 1, BFD_RELOC_8_PCREL);
 
       /* Now create the unconditional branch + fixup to the
 	 final target.  */
@@ -570,9 +577,11 @@ md_convert_frag (abfd, sec, fragP)
 	}
       fragP->fr_literal[offset + 1] = opcode;
 
-      /* Set the displacement bits so that we branch around
-	 the unconditional branch.  */
-      fragP->fr_literal[offset + 2] = 0x6;
+      /* Create a fixup for the reversed conditional branch.  */
+      sprintf (buf, "%s_%d", FAKE_LABEL_NAME, label_count++);
+      fix_new (fragP, fragP->fr_fix + 2, 1,
+	       symbol_new (buf, sec, 0, fragP->fr_next),
+	       fragP->fr_offset + 2, 1, BFD_RELOC_8_PCREL);
 
       /* Now create the unconditional branch + fixup to the
 	 final target.  */
@@ -648,9 +657,11 @@ md_convert_frag (abfd, sec, fragP)
 	}
       fragP->fr_literal[offset + 1] = opcode;
 
-      /* Set the displacement bits so that we branch around
-	 the unconditional branch.  */
-      fragP->fr_literal[offset + 2] = 0x8;
+      /* Create a fixup for the reversed conditional branch.  */
+      sprintf (buf, "%s_%d", FAKE_LABEL_NAME, label_count++);
+      fix_new (fragP, fragP->fr_fix + 2, 1,
+	       symbol_new (buf, sec, 0, fragP->fr_next),
+	       fragP->fr_offset + 2, 1, BFD_RELOC_8_PCREL);
 
       /* Now create the unconditional branch + fixup to the
 	 final target.  */
@@ -951,7 +962,8 @@ md_assemble (str)
 	      /* If this operand can be promoted, and it doesn't
 		 fit into the allocated bitfield for this insn,
 		 then promote it (ie this opcode does not match).  */
-	      if (operand->flags & MN10200_OPERAND_PROMOTE
+	      if (operand->flags
+		  & (MN10200_OPERAND_PROMOTE | MN10200_OPERAND_RELAX)
 		  && ! check_operand (insn, operand, ex.X_add_number))
 		{
 		  input_line_pointer = hold;
@@ -1193,7 +1205,7 @@ tc_gen_reloc (seg, fixp)
      fixS *fixp;
 {
   arelent *reloc;
-  reloc = (arelent *) bfd_alloc_by_size_t (stdoutput, sizeof (arelent));
+  reloc = (arelent *) xmalloc (sizeof (arelent));
 
   reloc->howto = bfd_reloc_type_lookup (stdoutput, fixp->fx_r_type);
   if (reloc->howto == (reloc_howto_type *) NULL)
@@ -1230,7 +1242,8 @@ md_estimate_size_before_relax (fragp, seg)
     return 3;
   if (fragp->fr_subtype == 6)
     {
-      if (!S_IS_DEFINED (fragp->fr_symbol))
+      if (!S_IS_DEFINED (fragp->fr_symbol)
+	  || seg != S_GET_SEGMENT (fragp->fr_symbol))
 	{
 	  fragp->fr_subtype = 7;
 	  return 5;
