@@ -1,5 +1,5 @@
 /* tc-sparc.c -- Assemble for the SPARC
-   Copyright (C) 1989, 90-95, 1996 Free Software Foundation, Inc.
+   Copyright (C) 1989, 90-96, 1997 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -28,6 +28,13 @@
 #include "opcode/sparc.h"
 
 static void sparc_ip PARAMS ((char *, const struct sparc_opcode **));
+static int in_signed_range PARAMS ((bfd_signed_vma, bfd_signed_vma));
+static int in_bitfield_range PARAMS ((bfd_signed_vma, bfd_signed_vma));
+static int sparc_ffs PARAMS ((unsigned int));
+static bfd_vma BSR PARAMS ((bfd_vma, int));
+static int cmp_reg_entry PARAMS ((const PTR, const PTR));
+static int parse_keyword_arg PARAMS ((int (*) (const char *), char **, int *));
+static int parse_const_expr_arg PARAMS ((char **, int *));
 
 /* Current architecture.  We don't bump up unless necessary.  */
 static enum sparc_opcode_arch_val current_architecture = SPARC_OPCODE_ARCH_V6;
@@ -153,6 +160,9 @@ struct sparc_it
 
 struct sparc_it the_insn, set_insn;
 
+static void output_insn
+  PARAMS ((const struct sparc_opcode *, struct sparc_it *));
+
 /* Return non-zero if VAL is in the range -(MAX+1) to MAX.  */
 
 static INLINE int
@@ -355,7 +365,7 @@ s_reserve (ignore)
 	  subseg_set (bss_section, 1); /* switch to bss */
 
 	  if (align)
-	    frag_align (align, 0); /* do alignment */
+	    frag_align (align, 0, 0); /* do alignment */
 
 	  /* detach from old frag */
 	  if (S_GET_SEGMENT(symbolP) == bss_section)
@@ -363,7 +373,7 @@ s_reserve (ignore)
 
 	  symbolP->sy_frag = frag_now;
 	  pfrag = frag_var (rs_org, 1, 1, (relax_substateT)0, symbolP,
-			    size, (char *)0);
+			    (offsetT) size, (char *)0);
 	  *pfrag = 0;
 
 	  S_SET_SEGMENT (symbolP, bss_section);
@@ -413,7 +423,7 @@ s_common (ignore)
   *p = 0;
   symbolP = symbol_find_or_make (name);
   *p = c;
-  if (S_IS_DEFINED (symbolP))
+  if (S_IS_DEFINED (symbolP) && ! S_IS_COMMON (symbolP))
     {
       as_bad ("Ignoring attempt to re-define symbol");
       ignore_rest_of_line ();
@@ -472,12 +482,12 @@ s_common (ignore)
 	  record_alignment (bss_section, align);
 	  subseg_set (bss_section, 0);
 	  if (align)
-	    frag_align (align, 0);
+	    frag_align (align, 0, 0);
 	  if (S_GET_SEGMENT (symbolP) == bss_section)
 	    symbolP->sy_frag->fr_symbol = 0;
 	  symbolP->sy_frag = frag_now;
-	  p = frag_var (rs_org, 1, 1, (relax_substateT) 0, symbolP, size,
-			(char *) 0);
+	  p = frag_var (rs_org, 1, 1, (relax_substateT) 0, symbolP,
+			(offsetT) size, (char *) 0);
 	  *p = 0;
 	  S_SET_SEGMENT (symbolP, bss_section);
 	  S_CLEAR_EXTERNAL (symbolP);
@@ -492,8 +502,7 @@ s_common (ignore)
 	  S_SET_ALIGN (symbolP, temp);
 #endif
 	  S_SET_EXTERNAL (symbolP);
-	  /* should be common, but this is how gas does it for now */
-	  S_SET_SEGMENT (symbolP, bfd_und_section_ptr);
+	  S_SET_SEGMENT (symbolP, bfd_com_section_ptr);
 	}
     }
   else
@@ -515,6 +524,11 @@ s_common (ignore)
 	;
       goto allocate_common;
     }
+
+#ifdef BFD_ASSEMBLER
+  symbolP->bsym->flags |= BSF_OBJECT;
+#endif
+
   demand_empty_rest_of_line ();
   return;
 
@@ -664,7 +678,7 @@ sparc_cons_align (nbytes)
     }
 
   p = frag_var (rs_align_code, 1, 1, (relax_substateT) 0,
-		(symbolS *) NULL, (long) nalign, (char *) NULL);
+		(symbolS *) NULL, (offsetT) nalign, (char *) NULL);
 
   record_alignment (now_seg, nalign);
 }
@@ -711,9 +725,13 @@ struct priv_reg_entry priv_reg_table[] =
 };
 
 static int
-cmp_reg_entry (p, q)
-     struct priv_reg_entry *p, *q;
+cmp_reg_entry (parg, qarg)
+     const PTR parg;
+     const PTR qarg;
 {
+  const struct priv_reg_entry *p = (const struct priv_reg_entry *) parg;
+  const struct priv_reg_entry *q = (const struct priv_reg_entry *) qarg;
+
   return strcmp (q->name, p->name);
 }
 
@@ -1109,7 +1127,7 @@ md_assemble (str)
 
 static int
 parse_keyword_arg (lookup_fn, input_pointerP, valueP)
-     int (*lookup_fn) ();
+     int (*lookup_fn) PARAMS ((const char *));
      char **input_pointerP;
      int *valueP;
 {
@@ -2303,7 +2321,6 @@ md_atof (type, litP, sizeP)
   int i,prec;
   LITTLENUM_TYPE words[MAX_LITTLENUMS];
   char *t;
-  char *atof_ieee ();
 
   switch (type)
     {
@@ -2398,7 +2415,7 @@ md_apply_fix3 (fixP, value, segment)
 #ifdef OBJ_ELF
   /* FIXME: SPARC ELF relocations don't use an addend in the data
      field itself.  This whole approach should be somehow combined
-     with the calls to bfd_perform_relocation.  Also, the value passed
+     with the calls to bfd_install_relocation.  Also, the value passed
      in by fixup_segment includes the value of a defined symbol.  We
      don't want to include the value of an externally visible symbol.  */
   if (fixP->fx_addsy != NULL)
@@ -2613,8 +2630,7 @@ tc_gen_reloc (section, fixp)
   arelent *reloc;
   bfd_reloc_code_real_type code;
 
-  reloc = (arelent *) bfd_alloc_by_size_t (stdoutput, sizeof (arelent));
-  assert (reloc != 0);
+  reloc = (arelent *) xmalloc (sizeof (arelent));
 
   reloc->sym_ptr_ptr = &fixp->fx_addsy->bsym;
   reloc->address = fixp->fx_frag->fr_address + fixp->fx_where;
@@ -2664,6 +2680,7 @@ tc_gen_reloc (section, fixp)
 	{
 	case BFD_RELOC_32_PCREL_S2:
 	  if (! S_IS_DEFINED (fixp->fx_addsy)
+	      || S_IS_COMMON (fixp->fx_addsy)
 	      || S_IS_EXTERNAL (fixp->fx_addsy)
 	      || S_IS_WEAK (fixp->fx_addsy))
 	    code = BFD_RELOC_SPARC_WPLT30;
@@ -2847,7 +2864,7 @@ struct option md_longopts[] = {
 #define OPTION_BIG_ENDIAN (OPTION_MD_BASE + 4)
   {"EB", no_argument, NULL, OPTION_BIG_ENDIAN},
 #endif
-  #define OPTION_ENFORCE_ALIGNED_DATA (OPTION_MD_BASE + 5)
+#define OPTION_ENFORCE_ALIGNED_DATA (OPTION_MD_BASE + 5)
   {"enforce-aligned-data", no_argument, NULL, OPTION_ENFORCE_ALIGNED_DATA},
   {NULL, no_argument, NULL, 0}
 };
@@ -2972,7 +2989,7 @@ md_show_usage (stream)
   fprintf (stream, "\
 			specify variant of SPARC architecture\n\
 -bump			warn when assembler switches architectures\n\
--sparc			ignored\n
+-sparc			ignored\n\
 --enforce-aligned-data	force .long, etc., to be aligned correctly\n");
 #ifdef OBJ_AOUT
   fprintf (stream, "\
