@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GLD; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /*
  ldfile.c
@@ -25,6 +25,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include "bfd.h"
 #include "sysdep.h"
+#include "bfdlink.h"
 #include "ld.h"
 #include "ldmisc.h"
 #include "ldexp.h"
@@ -44,11 +45,16 @@ unsigned long ldfile_output_machine;
 enum bfd_architecture ldfile_output_architecture;
 search_dirs_type *search_head;
 
+#ifndef MPW
 #ifdef VMS
 char *slash = "";
 #else
 char *slash = "/";
 #endif
+#else /* MPW */
+/* The MPW path char is a colon. */
+char *slash = ":";
+#endif /* MPW */
 
 /* LOCAL */
 
@@ -63,8 +69,9 @@ typedef struct search_arch
 static search_arch_type *search_arch_head;
 static search_arch_type **search_arch_tail_ptr = &search_arch_head;
  
-static boolean try_open_bfd PARAMS ((const char *attempt,
-				     lang_input_statement_type *entry));
+static boolean ldfile_open_file_search
+  PARAMS ((const char *arch, lang_input_statement_type *,
+	   const char *lib, const char *suffix));
 static FILE *try_open PARAMS ((const char *name, const char *exten));
 
 void
@@ -84,8 +91,8 @@ ldfile_add_library_path (name, cmdline)
 
 /* Try to open a BFD for a lang_input_statement.  */
 
-static boolean
-try_open_bfd (attempt, entry)
+boolean
+ldfile_try_open_bfd (attempt, entry)
      const char *attempt;
      lang_input_statement_type *entry;
 {
@@ -98,13 +105,17 @@ try_open_bfd (attempt, entry)
   if (entry->the_bfd != NULL)
     return true;
   else
-    return false;
+    {
+      if (bfd_get_error () == bfd_error_invalid_target)
+	einfo ("%F%P: invalid BFD target `%s'\n", entry->target);
+      return false;
+    }
 }
 
 /* Search for and open the file specified by ENTRY.  If it is an
    archive, use ARCH, LIB and SUFFIX to modify the file name.  */
 
-boolean
+static boolean
 ldfile_open_file_search (arch, entry, lib, suffix)
      const char *arch;
      lang_input_statement_type *entry;
@@ -117,7 +128,7 @@ ldfile_open_file_search (arch, entry, lib, suffix)
      directory first.  */
   if (! entry->is_archive)
     {
-      if (try_open_bfd (entry->filename, entry))
+      if (ldfile_try_open_bfd (entry->filename, entry))
 	return true;
     }
 
@@ -127,6 +138,12 @@ ldfile_open_file_search (arch, entry, lib, suffix)
     {
       char *string;
 
+      if (entry->dynamic && ! link_info.relocateable)
+	{
+	  if (ldemul_open_dynamic_archive (arch, search, entry))
+	    return true;
+	}
+
       string = (char *) xmalloc (strlen (search->name)
 				 + strlen (slash)
 				 + strlen (lib)
@@ -143,7 +160,7 @@ ldfile_open_file_search (arch, entry, lib, suffix)
       else
 	sprintf (string, "%s%s%s", search->name, slash, entry->filename);
 
-      if (try_open_bfd (string, entry))
+      if (ldfile_try_open_bfd (string, entry))
 	{
 	  entry->filename = string;
 	  return true;
@@ -166,7 +183,7 @@ ldfile_open_file (entry)
 
   if (! entry->search_dirs_flag)
     {
-      if (try_open_bfd (entry->filename, entry))
+      if (ldfile_try_open_bfd (entry->filename, entry))
 	return;
     }
   else
@@ -178,11 +195,6 @@ ldfile_open_file (entry)
 	   arch != (search_arch_type *) NULL;
 	   arch = arch->next)
 	{
-	  if (config.dynamic_link)
-	    {
-	      if (ldemul_open_dynamic_archive (arch->name, entry))
-		return;
-	    }
 	  if (ldfile_open_file_search (arch->name, entry, "lib", ".a"))
 	    return;
 #ifdef VMS
@@ -205,27 +217,33 @@ try_open (name, exten)
   FILE *result;
   char buff[1000];
 
-  result = fopen(name, "r");
-  if (trace_file_tries == true) {
-    if (result == (FILE *)NULL) {
-      info_msg ("cannot find ");
+  result = fopen (name, "r");
+  if (trace_file_tries)
+    {
+      if (result == NULL)
+	info_msg ("cannot find script file ");
+      else
+	info_msg ("opened script file ");
+      info_msg ("%s\n",name);
     }
-    info_msg ("%s\n",name);
-  }
-  if (result != (FILE *)NULL) {
-    return result;
-  }
 
-  if (*exten) {
-    sprintf(buff, "%s%s", name, exten);
-    result = fopen(buff, "r");
-    if (trace_file_tries == true) {
-      if (result == (FILE *)NULL) {
-	info_msg ("cannot find ");
-      }
-      info_msg ("%s\n", buff);
+  if (result != NULL)
+    return result;
+
+  if (*exten)
+    {
+      sprintf (buff, "%s%s", name, exten);
+      result = fopen (buff, "r");
+      if (trace_file_tries)
+	{
+	  if (result == NULL)
+	    info_msg ("cannot find script file ");
+	  else
+	    info_msg ("opened script file ");
+	  info_msg ("%s\n", buff);
+	}
     }
-  }
+
   return result;
 }
 
@@ -345,7 +363,7 @@ ldfile_add_arch (in_name)
 {
   char *name = buystring(in_name);
   search_arch_type *new =
-    (search_arch_type *)xmalloc((bfd_size_type)(sizeof(search_arch_type)));
+    (search_arch_type *) xmalloc (sizeof (search_arch_type));
 
   ldfile_output_machine_name = in_name;
 
@@ -366,7 +384,7 @@ void
 ldfile_set_output_arch (string)
      CONST char *string;
 {
-  bfd_arch_info_type *arch = bfd_scan_arch(string);
+  const bfd_arch_info_type *arch = bfd_scan_arch(string);
 
   if (arch) {
     ldfile_output_architecture = arch->arch;
