@@ -88,7 +88,8 @@ int parsing_defsym = 0;
 #define OPTION_UR			(OPTION_TRADITIONAL_FORMAT + 1)
 #define OPTION_VERBOSE			(OPTION_UR + 1)
 #define OPTION_VERSION			(OPTION_VERBOSE + 1)
-#define OPTION_WARN_COMMON		(OPTION_VERSION + 1)
+#define OPTION_VERSION_SCRIPT		(OPTION_VERSION + 1)
+#define OPTION_WARN_COMMON		(OPTION_VERSION_SCRIPT + 1)
 #define OPTION_WARN_CONSTRUCTORS	(OPTION_WARN_COMMON + 1)
 #define OPTION_WARN_MULTIPLE_GP		(OPTION_WARN_CONSTRUCTORS + 1)
 #define OPTION_WARN_ONCE		(OPTION_WARN_MULTIPLE_GP + 1)
@@ -294,6 +295,8 @@ static const struct ld_option ld_options[] =
       '\0', NULL, "Output lots of information during link", TWO_DASHES },
   { {"dll-verbose", no_argument, NULL, OPTION_VERBOSE}, /* Linux.  */
       '\0', NULL, NULL, NO_HELP },
+  { {"version-script", required_argument, NULL, OPTION_VERSION_SCRIPT },
+      '\0', "FILE", "Read version information script", TWO_DASHES },
   { {"warn-common", no_argument, NULL, OPTION_WARN_COMMON},
       '\0', NULL, "Warn about duplicate common symbols", TWO_DASHES },
   { {"warn-constructors", no_argument, NULL, OPTION_WARN_CONSTRUCTORS},
@@ -702,7 +705,7 @@ parse_args (argc, argv)
 	case OPTION_VERSION:
 	  /* This output is intended to follow the GNU standards document.  */
 	  printf ("GNU ld %s\n", ld_program_version);
-	  printf ("Copyright 1996 Free Software Foundation, Inc.\n");
+	  printf ("Copyright 1997 Free Software Foundation, Inc.\n");
 	  printf ("\
 This program is free software; you may redistribute it under the terms of\n\
 the GNU General Public License.  This program has absolutely no warranty.\n");
@@ -718,6 +721,20 @@ the GNU General Public License.  This program has absolutely no warranty.\n");
 	  }
 	  xexit (0);
 	  break;
+	case OPTION_VERSION_SCRIPT:
+	  /* This option indicates a small script that only specifies
+             version information.  Read it, but don't assume that
+             we've seen a linker script.  */
+	  {
+	    boolean hold_had_script;
+
+	    hold_had_script = had_script;
+	    ldfile_open_command_file (optarg);
+	    had_script = hold_had_script;
+	    parser_input = input_version_script;
+	    yyparse ();
+	  }
+	  break;
 	case OPTION_WARN_COMMON:
 	  config.warn_common = true;
 	  break;
