@@ -1,5 +1,5 @@
 /* Demangler for GNU C++ 
-   Copyright 1989, 1991, 1994, 1995, 1996 Free Software Foundation, Inc.
+   Copyright 1989, 1991, 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
    Written by James Clark (jjc@jclark.uucp)
    Rewritten by Fred Fish (fnf@cygnus.com) for ARM and Lucid demangling
    
@@ -39,11 +39,13 @@ Boston, MA 02111-1307, USA.  */
 extern char *xmalloc PARAMS((unsigned));
 extern char *xrealloc PARAMS((char *, unsigned));
 
-char *
+static const char *mystrstr PARAMS ((const char *, const char *));
+
+static const char *
 mystrstr (s1, s2)
-     char *s1, *s2;
+     const char *s1, *s2;
 {
-  register char *p = s1;
+  register const char *p = s1;
   register int len = strlen (s2);
 
   for (; (p = strchr (p, *s2)) != 0; p++)
@@ -222,6 +224,16 @@ static int
 demangle_template PARAMS ((struct work_stuff *work, const char **, string *,
 			   string *));
 
+static int
+arm_pt PARAMS ((struct work_stuff *, const char *, int, const char **,
+		const char **));
+
+static void
+demangle_arm_pt PARAMS ((struct work_stuff *, const char **, int, string *));
+
+static int
+demangle_class_name PARAMS ((struct work_stuff *, const char **, string *));
+
 static int
 demangle_qualified PARAMS ((struct work_stuff *, const char **, string *,
 			    int, int));
@@ -472,21 +484,6 @@ cplus_mangle_opname (opname, options)
   return (0);
 }
 
-/* Check to see whether MANGLED can match TEXT in the first TEXT_LEN
-   characters.  */
-
-int cplus_match (mangled, text, text_len)
-     const char *mangled;
-     char *text;
-     int text_len;
-{
-  if (strncmp (mangled, text, text_len) != 0) {
-    return(0); /* cannot match either */
-  } else {
-    return(1); /* matches mangled, may match demangled */
-  }
-}
-
 /* char *cplus_demangle (const char *mangled, int options)
 
    If MANGLED is a mangled function name produced by GNU C++, then
@@ -1614,9 +1611,8 @@ gnu_special (work, mangled, declp)
 	  success = demangle_template (work, mangled, declp, 0);
 	  break;
 	default:
-	  n = consume_count (mangled);
-	  string_appendn (declp, *mangled, n);
-	  (*mangled) += n;
+	  success = demangle_fund_type (work, mangled, declp);
+	  break;
 	}
       if (success && **mangled != '\0')
 	success = 0;
@@ -2864,6 +2860,10 @@ string_prependn (p, s, n)
 
 #ifdef MAIN
 
+static void demangle_it PARAMS ((char *));
+static void usage PARAMS ((FILE *, int));
+static void fatal PARAMS ((char *));
+
 static void
 demangle_it (mangled_name)
      char *mangled_name;
