@@ -2013,6 +2013,11 @@ OP_J (bytemode, aflag, dflag)
     case b_mode:
       FETCH_DATA (the_info, codep + 1);
       disp = *(char *)codep++;
+
+      /* sign extend number */
+      if (disp >= 1<<7) {
+	disp -= 1<<8;
+      }
       break;
     case v_mode:
       if (dflag)
@@ -2020,6 +2025,10 @@ OP_J (bytemode, aflag, dflag)
       else
 	{
 	  disp = (short)get16 ();
+	  /* sign extend number */
+	  if (disp >= 1<<15) {
+	    disp -= 1<<16;
+	  }
 	  /* for some reason, a data16 prefix on a jump instruction
 	     means that the pc is masked to 16 bits after the
 	     displacement is added!  */
